@@ -1063,6 +1063,9 @@ iiop_connection_server_accept(GIOPConnection *connection)
   if(newfd >= 0) {
     newcnx = GIOP_CONNECTION(iiop_connection_from_fd(newfd,
 						     IIOP_CONNECTION(connection)));
+#ifdef GIOP_INTERNAL_DEBUG
+    g_warning ("New connection '%p'", newcnx);
+#endif
     GIOP_CONNECTION(newcnx)->orb_data = connection->orb_data;
     switch(IIOP_CONNECTION(connection)->icnxtype) {
     case IIOP_USOCK: newcnx->is_auth = TRUE; break;
