@@ -178,16 +178,22 @@ ORBit_marshal_value(GIOPSendBuffer *buf,
 	   find out which value we want to use */
 	{
 	    CORBA_TypeCode utc;
+	    guint max_size = 0;
+	    gpointer newval;
 
-	    *val = ALIGN_ADDRESS(*val, ALIGNOF_CORBA_STRUCT);
+	    *val = newval = ALIGN_ADDRESS(*val, ALIGNOF_CORBA_STRUCT);
 
-	    utc = ORBit_get_union_tag(tc, val, TRUE);
-
-	    *val = ALIGN_ADDRESS(*val, ALIGNOF_CORBA_STRUCT);
+	    utc = ORBit_get_union_tag(tc, val, FALSE);
 
 	    ORBit_marshal_value(buf, val, tc->discriminator, mi);
+/*	    *val = ALIGN_ADDRESS(*val, ALIGNOF_CORBA_UNION); */
+
 	    *val = ALIGN_ADDRESS(*val, ORBit_find_alignment(tc));
+	    max_size = ORBit_gather_alloc_info(tc) - ((guchar *)*val - (guchar *)newval);
+
+	    newval = ((char *)*val) + max_size;
 	    ORBit_marshal_value(buf, val, utc, mi);
+	    *val = newval;
 	}
 	break;
     case CORBA_tk_wstring:
